
.. _amrclaw_tests_advection_2d_bc:

Two-dimensional advection of a square pulse with custom BCs
===========================================================

Variation on the square pulse advection test where a custom boundary condition
has been specified on the left boundary and all other boundaries are set to 
extrapolate.

